%define __python %{__python3}

Name:		msec
Version:	2.3
Release:	%mkrel 1
Summary:	Security Level management Linux distributions
License:	GPLv2+
Group:		System/Base
Url:		http://gitweb.mageia.org/software/msec/
Source0:	http://gitweb.mageia.org/software/msec/snapshot/%{name}-%{version}.tar.xz
Requires:	perl-base
Requires:	diffutils
Requires:	gawk
Requires:	coreutils
Requires:	iproute2
Requires:	setup
Requires:	chkconfig
Requires:	mailx
Requires:	python3
Requires:	gettext
Recommends:	sectool
# at least xargs is used
Requires:	findutils
# ensure sysctl.conf and inittab are present before installing msec
Requires(post):	initscripts

Requires(pre):		rpm-helper >= 0.4
Requires(postun):	rpm-helper >= 0.4

# using s2u for desktop notifications
# it should be pulled by xinit to reduce basesystem size
# Suggests:	s2u >= 0.9

Conflicts:	passwd < 0.67
BuildRequires:	python3
# ovitters: pkgconfig(gobject-introspection-1.0) includes script to determine typelib() auto buildrequires
BuildRequires:	pkgconfig(gobject-introspection-1.0)

%description
The Security package is designed to provide security features to Linux users.
It allows to select from a set of preconfigured security levels, and supports
custom permission settings, user-specified levels, and several security
utilities. This packages includes main msec application and several programs
that will be run periodically in order to test the security of your system and
alert you if needed.

%package gui
Summary:	Graphical msec interface
Group:		System/Configuration
Requires:	python3-gobject3
Requires:	msec
Requires:	drakconf-icons

%description gui
The Security package is designed to provide security features to the Linux
users. It allows to select from a set of preconfigured security levels, and also
supports custom permission settings, user-specified levels, and several security
utilities. This packages includes graphical interface to control and tune msec
permissions.


%prep
%autosetup

%build
%make_build CFLAGS="%{optflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"

%install
%make_install

mkdir -p %{buildroot}/%{_sysconfdir}/{logrotate.d,profile.d}
touch %{buildroot}/var/log/security.log
touch %{buildroot}/etc/security/msec/security.conf
touch %{buildroot}/etc/security/msec/perms.conf
# init script
install -d %{buildroot}/%{_initrddir}
install -m755 %{_builddir}/%{name}-%{version}/msec.init %{buildroot}/%{_initrddir}/%{name}
mkdir -p %{buildroot}/etc/X11/xinit.d
touch %{buildroot}/etc/X11/xinit.d/msec

%find_lang %name --with-man

%pre
%_pre_groupadd xgrp
%_pre_groupadd ntools
%_pre_groupadd ctools

%preun
%_preun_service msec

%post
%_post_service msec

touch /var/log/security.log

if [ $1 != 1 ]; then
        # since 0.80.3, msec has its own upgrade script, which handles upgrades from previous versions
        /usr/share/msec/upgrade.sh
fi

# creating default configuration if not installed by installer
if [ "$DURING_INSTALL" != "1" ]; then
	if [ ! -s /etc/security/msec/security.conf ]; then
		# creating default level configuration
		cp -f /etc/security/msec/level.standard /etc/security/msec/security.conf
	fi

	if [ ! -s /etc/security/msec/perms.conf ]; then
		# creating default level configuration
		cp -f /etc/security/msec/perm.standard /etc/security/msec/perms.conf
	fi
fi

%postun

if [ $1 = 0 ]; then
	# cleanup crontabs on package removal
	rm -f /etc/cron.*/msec
fi

%_postun_groupdel xgrp
%_postun_groupdel ntools
%_postun_groupdel ctools

%files -f %{name}.lang
%doc AUTHORS COPYING README*
%doc ChangeLog doc/*.txt
%_bindir/promisc_check
%_bindir/msec_find
%{_initrddir}/%{name}
%_sbindir/msec
%_sbindir/msecperms
%_datadir/msec/msec.py*
%_datadir/msec/config.py*
%_datadir/msec/libmsec.py*
%_datadir/msec/msecperms.py*
%_datadir/msec/tools.py*
%_datadir/msec/version.py*
%_datadir/msec/*.sh
%_datadir/msec/plugins/*
%_datadir/msec/scripts/*
%_datadir/msec/__pycache__/
%_mandir/*/*.*
%dir /var/log/security
%dir /etc/security/msec
%config /etc/security/msec/level.*
%config /etc/security/msec/perm.*
%config /etc/security/msec/server.*
%config(noreplace) /etc/security/msec/security.conf
%config(noreplace) /etc/security/msec/perms.conf
%config(noreplace) /etc/logrotate.d/msec
/etc/profile.d/*msec*

%config %attr(0755,root,root) /etc/X11/xinit.d/msec

%ghost /var/log/security.log
%ghost /var/log/msec.log

%files gui
%_sbindir/msecgui
%_datadir/msec/msecgui.py*
%_datadir/msec/help.py*
%_datadir/msec/msec.png


%changelog
* Mon Mar 13 2017 akien <akien> 2.3-1.mga6
+ Revision: 1092454
- Version 2.3

* Sun Sep 25 2016 daviddavid <daviddavid> 2.2-1.mga6
+ Revision: 1056156
- new version: 2.2 (fixes mga#19335)
- msec.png permission is now fixed directly in source

* Tue Sep 20 2016 ghibo <ghibo> 2.1-2.mga6
+ Revision: 1054742
- fix msec.png permission

* Sat Apr 16 2016 akien <akien> 2.1-1.mga6
+ Revision: 1002912
- Version 2.1

* Fri Feb 12 2016 umeabot <umeabot> 2.0-3.mga6
+ Revision: 956187
- Mageia 6 Mass Rebuild

* Sat Aug 29 2015 tv <tv> 2.0-2.mga6
+ Revision: 870825
- fix python3 requires

* Sat Aug 29 2015 tv <tv> 2.0-1.mga6
+ Revision: 870801
- fix build with python3
- adjust deps for python3
- fix unable to add an exception (mga#16574)
- switch to python3 (mga#16524)
- use systemctl instead of consolehelper (mga#16084)
- fix unable to add an exception (mga#16574)
- switch to python3 (mga#16524)
- use systemctl instead of consolehelper (mga#16084)

* Sun Aug 02 2015 daviddavid <daviddavid> 1.13-2.mga6
+ Revision: 860835
- add missing requires for gettext to msec main pkg (mga#15146)

* Thu Jul 30 2015 marja <marja> 1.13-1.mga6
+ Revision: 859023
- New version that better fixes mga#13837

* Sat Jul 25 2015 tv <tv> 1.12-1.mga6
+ Revision: 857515
- msecgui: fix gtk3 regression (mga#13837)

* Wed May 20 2015 neoclust <neoclust> 1.11-2.mga5
+ Revision: 822433
- Fix URL

* Wed May 20 2015 neoclust <neoclust> 1.11-1.mga5
+ Revision: 822432
- process_events(): Fix use of main_iteration() mga#15985

* Tue May 19 2015 akien <akien> 1.10-1.mga5
+ Revision: 822389
- fix use of get_iter_root

* Mon May 18 2015 tv <tv> 1.9-1.mga5
+ Revision: 822282
- translation update

* Fri May 01 2015 tv <tv> 1.8-1.mga5
+ Revision: 820945
- msecgui: fix broken config buttons after migration to gtk3
  (Philippe Makowski, mga#14777)

* Fri May 01 2015 tv <tv> 1.7-1.mga5
+ Revision: 820940
- msecgui: Fix broken saving feature after migration to gtk3
  by adding "label=" arguments for Gtk.Expander calls
  (Thierry Vignaud, mga#14586)
- updated translations

* Mon Feb 09 2015 ennael <ennael> 1.6-1.mga5
+ Revision: 814339
- update translations

* Fri Jan 02 2015 tv <tv> 1.5-1.mga5
+ Revision: 808063
- s/Mandriva/Mageia/
- updated translations

* Wed Oct 15 2014 umeabot <umeabot> 1.4-3.mga5
+ Revision: 748476
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4-2.mga5
+ Revision: 682667
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

  + ovitters <ovitters>
    - add gobject-introspection BR for typelib auto BR

* Sun Feb 16 2014 tv <tv> 1.4-1.mga5
+ Revision: 592780
- fix some gettext calls broken by auto migration to gtk3 (Yuri)

* Tue Feb 11 2014 tv <tv> 1.3-1.mga5
+ Revision: 589354
- fix menu accelerators after conversion to gtk3

* Tue Feb 11 2014 tv <tv> 1.2-1.mga5
+ Revision: 589347
- revert "don't pass '--noscripts' to 'rpm -Va' (#62644)"
- requires python-gi instead of pygtk2.0

* Mon Feb 10 2014 tv <tv> 1.1-1.mga5
+ Revision: 589035
- fix embedding in mcc (bgo#721226)
- fix treating UTF-8 strings as ascii

* Sun Feb 09 2014 tv <tv> 1.0-1.mga5
+ Revision: 587597
- convert from gtk2 to gtk3
- don't pass '--noscripts' to 'rpm -Va' (#62644)
- rotate /var/log/msec.log together with /var/log/security.log
- properly handle cases when /etc/sysconfig/i18n is not there
- properly handling startx parsing (#60440)

* Sat Oct 19 2013 umeabot <umeabot> 0.80.10-14.mga4
+ Revision: 522550
- Mageia 4 Mass Rebuild

* Sun Mar 17 2013 lmenut <lmenut> 0.80.10-13.mga3
+ Revision: 403607
- rebuild for new rpm-mageia-setup
  do not own man lang directories (mga #9055)

* Wed Jan 23 2013 fwang <fwang> 0.80.10-12.mga3
+ Revision: 391502
- update rpm group

* Sat Jan 12 2013 umeabot <umeabot> 0.80.10-11.mga3
+ Revision: 360460
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 26 2012 tv <tv> 0.80.10-10.mga2
+ Revision: 201803
- stop suggesting msec-gui (bloats minimal install)

* Mon Jan 23 2012 tv <tv> 0.80.10-9.mga2
+ Revision: 200331
- unbloat: no more postfix in basesystem (MTA should be installed when needed)

* Sun Jan 08 2012 tmb <tmb> 0.80.10-8.mga2
+ Revision: 193143
- rebuild for missing signature

* Sun Jan 08 2012 luigiwalser <luigiwalser> 0.80.10-7.mga2
+ Revision: 193124
- suggest sectool instead of require (not used by default)

* Sun Jan 08 2012 dmorgan <dmorgan> 0.80.10-6.mga2
+ Revision: 193105
- Disable sectool check by default ( mga #2808)

* Sun Jan 08 2012 dmorgan <dmorgan> 0.80.10-5.mga2
+ Revision: 193027
- Do not tries to change svn folder perms by default ( mga #3284)

* Tue Oct 25 2011 dmorgan <dmorgan> 0.80.10-4.mga2
+ Revision: 158059
- Fix use of mageiaupdate

  + doktor5000 <doktor5000>
    - add Require on sendmail-command to allow successful sending of reports
    - use proper URL
    - add Requires on sectool to partly fix (mga#2255)
    - require drakconf-icons for msec-gui to make sure used icons are existent
    - exchange blank updates icon to proper one after rebrand

* Wed Feb 16 2011 ahmad <ahmad> 0.80.10-2.mga1
+ Revision: 52710
- use a generic description/summary
- use non-versioned Requires, we have recent enough versions anyway

* Mon Jan 24 2011 spuhler <spuhler> 0.80.10-1.mga1
+ Revision: 36052
- removed buildroot definition from .spec
- imported package msec

